function A = gravAccelN (M, X, nH)
% function A = gravAccel (X)
%
% Find the acceleration due to gravity of a set of point masses.
% Gravitational constant not factored in (ie: set to 1).
% O(n) algorithm.
%
% parameters:
%   M  = row vector of masses.
%   X  = matrix of mass positions where row i is position of mass i.
%   nH = number of levels in space hierarchy
%
% written by Robert Osada

% create hierarchy
// TODO

% recurse on hierarchy
// TODO

% push acceleration to masses
// TODO